==> flexible-process-springboot-1.4.1.Final-sources.jar: org/kie/flexible/kogito/example/ServiceDeskModelInput.java <==
/*
 * Copyright 2020 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.kie.flexible.kogito.example;

import java.util.Map;
import java.util.HashMap;

@org.kie.kogito.codegen.Generated(value = "kogito-codegen", reference = "serviceDesk", name = "ServiceDesk", hidden = true)
public class ServiceDeskModelInput implements org.kie.kogito.Model {

    @Override
    public Map<String, Object> toMap() {
        Map<String, Object> params = new HashMap();
        params.put("supportCase", this.supportCase);
        params.put("supportGroup", this.supportGroup);
        return params;
    }

    @Override
    public void fromMap(Map<String, Object> params) {
        fromMap(null, params);
    }

    @Override
    public void update(Map<String, Object> params) {
        fromMap(params);
    }

    public void fromMap(String id, Map<String, Object> params) {
        this.supportCase = (org.kie.flexible.kogito.example.model.SupportCase) params.get("supportCase");
        this.supportGroup = (java.lang.String) params.get("supportGroup");
    }

    @org.kie.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "supportCase")
    @javax.validation.Valid()
    private org.kie.flexible.kogito.example.model.SupportCase supportCase;

    public org.kie.flexible.kogito.example.model.SupportCase getSupportCase() {
        return supportCase;
    }

    public void setSupportCase(org.kie.flexible.kogito.example.model.SupportCase supportCase) {
        this.supportCase = supportCase;
    }

    @org.kie.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "supportGroup")
    @javax.validation.Valid()
    private java.lang.String supportGroup;

    public java.lang.String getSupportGroup() {
        return supportGroup;
    }

    public void setSupportGroup(java.lang.String supportGroup) {
        this.supportGroup = supportGroup;
    }

    public ServiceDeskModel toModel() {
        ServiceDeskModel result = new ServiceDeskModel();
        result.setSupportCase(getSupportCase());
        result.setSupportGroup(getSupportGroup());
        return result;
    }
}

==> flexible-process-springboot-1.7.0.Final-sources.jar: org/kie/flexible/kogito/example/ServiceDeskModelInput.java <==
/*
 * Copyright 2020 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.kie.flexible.kogito.example;

import java.util.Map;
import java.util.HashMap;

@org.kie.kogito.codegen.Generated(value = "kogito-codegen", reference = "serviceDesk", name = "ServiceDesk", hidden = true)
public class ServiceDeskModelInput implements org.kie.kogito.Model {

    @Override
    public Map<String, Object> toMap() {
        Map<String, Object> params = new HashMap<>();
        params.put("supportCase", this.supportCase);
        params.put("supportGroup", this.supportGroup);
        return params;
    }

    @Override
    public void fromMap(Map<String, Object> params) {
        fromMap(null, params);
    }

    @Override
    public void update(Map<String, Object> params) {
        fromMap(params);
    }

    public void fromMap(String id, Map<String, Object> params) {
        this.supportCase = (org.kie.flexible.kogito.example.model.SupportCase) params.get("supportCase");
        this.supportGroup = (java.lang.String) params.get("supportGroup");
    }

    @org.kie.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "supportCase")
    @javax.validation.Valid()
    private org.kie.flexible.kogito.example.model.SupportCase supportCase;

    public org.kie.flexible.kogito.example.model.SupportCase getSupportCase() {
        return supportCase;
    }

    public void setSupportCase(org.kie.flexible.kogito.example.model.SupportCase supportCase) {
        this.supportCase = supportCase;
    }

    @org.kie.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "supportGroup")
    @javax.validation.Valid()
    private java.lang.String supportGroup;

    public java.lang.String getSupportGroup() {
        return supportGroup;
    }

    public void setSupportGroup(java.lang.String supportGroup) {
        this.supportGroup = supportGroup;
    }

    public ServiceDeskModel toModel() {
        ServiceDeskModel result = new ServiceDeskModel();
        result.setSupportCase(getSupportCase());
        result.setSupportGroup(getSupportGroup());
        return result;
    }
}
